%define with_python3 1

Name:           satyr
Version:        0.42
Release:        1
Summary:        Tools to create anonymous, machine-friendly problem reports
License:        GPLv2+
URL:            https://github.com/abrt/satyr
Source0:        https://github.com/abrt/%{name}/archive/%{version}.tar.gz

Requires:       json-c nettle glib2 >= 2.43.4
BuildRequires:  elfutils-devel elfutils-libelf-devel binutils-devel rpm-devel 
BuildRequires:  doxygen pkgconfig automake gcc-c++ git libtool
BuildRequires:  pkgconfig(json-c)  nettle  nettle-devel gperf glib2-devel
# we should require gdb for test suite
BuildRequires:  gdb

%if %{with_python3}
BuildRequires:  python3-devel python3-sphinx
%endif

%description
Satyr is a collection of low-level algorithms for program failure processing,
analysis, and reporting supporting kernel space, user space, Python, and Java
programs.  Considering failure processing, it allows to parse failure
description from various sources such as GDB-created stack traces, Python stack
traces with a description of uncaught exception, and kernel oops message.
Information can also be extracted from the core dumps of unexpectedly
terminated user space processes and from the machine executable code of
binaries.  Considering failure analysis, the stack traces of failed processes
can be normalized, trimmed, and compared.  Clusters of similar stack traces can
be calculated.  In multi-threaded stack traces, the threads that caused the
failure can be discovered.  Considering failure reporting, the library can
generate a failure report in a well-specified format, and the report can be
sent to a remote machine.

%package        devel
Summary:        Header files for satyr
Requires:       %{name} = %{version}-%{release}

%description    devel
Header files for satyr.


%if %{with_python3}
%package     -n python3-satyr
Summary:        python3 for satyr
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-python3 = %{version}-%{release}
Provides:       %{name}-python3%{?_isa} = %{version}-%{release}
Obsoletes:      %{name}-python3 < 0.24
%{?python_provide:%python_provide python3-satyr}

%description -n python3-satyr
python3 for satyr
%endif

%package_help

%prep
%define __scm_apply_git(qp:m:) %{__git} am
%autosetup -n %{name}-%{version} -p1
sed -i 's/dist_doc_DATA = README.md//' Makefile.am
bash autogen.sh

%build
%configure  --enable-doxygen-docs

%make_build

%install
%make_install
%delete_la
    
%check
make check|| {
     find tests/testsuite.dir -name "testsuite.log" -print -exec cat '{}' \;
     exit 1
}


%ldconfig_scriptlets
%files
%defattr(-,root,root)
%license COPYING
%{_bindir}/satyr
%{_libdir}/lib*.so.*

%files          devel
%defattr(-,root,root)
%{_includedir}/*
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*

%if %{with_python3}
%files  -n python3-satyr
%{python3_sitearch}/*
%endif

%files    help
%defattr(-,root,root)
%doc README.md NEWS
%{_mandir}/*

%changelog
* Mon Jul 17 2023 zhangpan <zhangpan103@h-partners.com> - 0.42-1
- update to 0.42

* Fri Feb 03 2023 zhangpan <zhangpan@h-partners.com> - 0.40-1
- update to 0.40

* Wed Oct 26 2022 zhouwenpei <zhouwenpei1@h-partners.com> - 0.38-4
- Rebuild for next release

* Tue Feb 22 2022 dongyuzhen <dongyuzhen@h-partners.com> - 0.38-3
- Test fix: add gdb buildrequires for fix core_stacktrace fail
- fix changelog

* Mon Jan 10 2022 yangcheng <yangcheng87@huawei.com> - 0.38-2
- no longer includes libstatyr.so.3

* Mon Dec 06 2021 wuchaochao <wuchaochao4@huawei.com> - 0.38-1
- update version to 0.38

* Wed Jul 21 2021 yushaogui <yushaogui@huawei.com> - 0.36-2
- Delete a buildrequires for gdb

* Fri Jan 29 2021 jinzhimin <jinzhimin2@huawei.com> - 0.36-1
- Upgrade to 0.36

* Tue Sep 8 2020 hanhui <hanhui15@huawei.com> - 0.30-2
- Type:bugfix
- ID:NA
- SUG:NA
- DESC:modify source url

* Mon Jul 27 2020 openEuler Buildteam <buildteam@openeuler.org> - 0.30-1
- update package

* Fri Feb 28 2020 hexiujun <hexiujun1@huawei.com> - 0.27-5
- Type:enhancement
- Id:NA
- SUG:NA
- DESC:use python2 explicitly in configure

* Wed Jan 22 2020 openEuler Buildteam <buildteam@openeuler.org> - 0.27-4
- Type:bugfix
- Id:NA
- SUG:NA
- DESC:add the definition of with_python2 and with_python3

* Tue Dec 31 2019 openEuler Buildteam <buildteam@openeuler.org> - 0.27-3
- Type:bugfix
- ID:NA
- SUG:NA
- DESC:optimization

* Fri Oct 11 2019 openEuler Buildteam <buildteam@openeuler.org> - 0.27-2
- Package init
